Pydap contributors (sorted alphabetically)
==========================================

* Roberto De Almeida
* James Gallagher
* Aleksandar Jelenak
* James Hiebert
* Stephan Hoyer
* **[SiggyF](https://github.com/SiggyF)**
* Aleksandar Jelenak
* Frederic Laliberte
* Mike McCann
* Lewis John McGibbney
* **[ocefpaf](https://github.com/ocefpaf)**
* Ghislain Antony Vaillant
